@@ -1,37 +1,52 @@
 import time
 from datetime import datetime, tzinfo
-from typing import Any, Callable
+from typing import Any, Callable, Mapping, Sequence, TypeAlias, TypedDict
 
 from .backend import Backend
-from .controller import Controller, Shutdown, Pause, Resume
+from .event import EventBridge, Shutdown, Pause, Resume
 from .process import TaskkitProcess
 from .result import Result
-from .scheduler import ScheduleEntry
+from .scheduler import ScheduleEntry, Schedule
 from .signal import SignalCaptured, capture_signals, signal
 from .task import Task, TaskHandler, DEFAULT_TASK_TTL
 from .utils import local_tz
 from .worker import EagerWorker
 
 
+class ScheduleEntryDict(TypedDict):
+    key: str
+    schedule: Schedule
+    group: str
+    name: str
+    data: Any
+
+
+ScheduleEntryCompat: TypeAlias = ScheduleEntry | ScheduleEntryDict
+ScheduleEntriesCompat: TypeAlias = Sequence[ScheduleEntryCompat]
+ScheduleEntriesCompatMapping: TypeAlias = Mapping[str, ScheduleEntriesCompat]
+
+
 class Kit:
     def __init__(self,
                  backend: Backend,
-                 controller: Controller,
+                 bridge: EventBridge,
                  handler: TaskHandler):
         self.backend = backend
-        self.controller = controller
+        self.bridge = bridge
         self.handler = handler
         self.eager_worker = EagerWorker(backend, handler)
 
     def start(self,
               num_processes: int,
               num_worker_threads_per_group: dict[str, int],
-              schedule_entries: dict[str, list[ScheduleEntry]] = {},
+              schedule_entries: ScheduleEntriesCompatMapping = {},
               tzinfo: tzinfo | None = None,
               should_restart: Callable[[TaskkitProcess], bool] = lambda _: False):
 
+        schedule_entries = self._ensure_schedule_entries(schedule_entries)
+
         def _start():
-            return self.start_process(
+            return self._start_process(
                 num_worker_threads_per_group=num_worker_threads_per_group,
                 schedule_entries=schedule_entries,
                 tzinfo=tzinfo,
@@ -63,26 +78,27 @@ class Kit:
     def start_processes(self,
                         num_processes: int,
                         num_worker_threads_per_group: dict[str, int],
-                        schedule_entries: dict[str, list[ScheduleEntry]] = {},
+                        schedule_entries: ScheduleEntriesCompatMapping = {},
                         tzinfo: tzinfo | None = None,
                         daemon: bool = True) -> list[TaskkitProcess]:
+        schedule_entries = self._ensure_schedule_entries(schedule_entries)
         return [
-            self.start_process(num_worker_threads_per_group,
-                               schedule_entries,
-                               tzinfo,
-                               daemon)
+            self._start_process(num_worker_threads_per_group,
+                                schedule_entries,
+                                tzinfo,
+                                daemon)
             for _ in range(num_processes)
         ]
 
-    def start_process(self,
-                      num_worker_threads_per_group: dict[str, int],
-                      schedule_entries: dict[str, list[ScheduleEntry]] = {},
-                      tzinfo: tzinfo | None = None,
-                      daemon: bool = True) -> TaskkitProcess:
+    def _start_process(self,
+                       num_worker_threads_per_group: dict[str, int],
+                       schedule_entries: dict[str, list[ScheduleEntry]] = {},
+                       tzinfo: tzinfo | None = None,
+                       daemon: bool = True) -> TaskkitProcess:
         p = TaskkitProcess(
             num_worker_threads_per_group=num_worker_threads_per_group,
             backend=self.backend,
-            controller=self.controller,
+            bridge=self.bridge,
             handler=self.handler,
             schedule_entries=schedule_entries,
             tzinfo=tzinfo or local_tz(),
@@ -90,6 +106,27 @@ class Kit:
         p.start()
         return p
 
+    def _ensure_schedule_entries(self, entries: ScheduleEntriesCompatMapping)\
+            -> dict[str, list[ScheduleEntry]]:
+
+        return {
+            k: [self._ensure_schedule_entry(e) for e in v]
+            for k, v in entries.items()
+        }
+
+    def _ensure_schedule_entry(self, entry: ScheduleEntry | ScheduleEntryDict)\
+            -> ScheduleEntry:
+        if isinstance(entry, dict):
+            return ScheduleEntry(
+                key=entry['key'],
+                schedule=entry['schedule'],
+                group=entry['group'],
+                name=entry['name'],
+                data=self.handler.encode_data(
+                    entry['group'], entry['name'], entry['data']),
+            )
+        return entry
+
     def initiate_task(self,
                       group: str,
                       name: str,
@@ -109,18 +146,18 @@ class Kit:
             'name': 'shutdown',
             'groups': None if groups is None else list(groups),
         }
-        self.controller.send_event(event)
+        self.bridge.send_event(event)
 
     def send_pause_event(self, groups: set[str] | None = None):
         event: Pause = {
             'name': 'pause',
             'groups': None if groups is None else list(groups),
         }
-        self.controller.send_event(event)
+        self.bridge.send_event(event)
 
     def send_resume_event(self, groups: set[str] | None = None):
         event: Resume = {
             'name': 'resume',
             'groups': None if groups is None else list(groups),
         }
-        self.controller.send_event(event)
+        self.bridge.send_event(event)
